@@ -11,5 +11,11 @@ from .post import PostManager, Post
 from .comment import CommentManager, Comment
 from .rating import Rating, PostRatingManager, PostRating, CommentRatingManager, CommentRating
 from .like import Like, PostLikeManager, PostLike, CommentLikeManager, CommentLike
+from .admonition_template import AdmonitionTemplateManager, AdmonitionTemplate
+from .admonition import AdmonitionManager, Admonition
+from .admonition_action import AdmonitionActionManager, AdmonitionAction
+from .correction_request import CorrectionRequestManager, CorrectionRequest
+from .correction_request_action import CorrectionRequestActionManager, CorrectionRequestAction
+
 
 
